@@ -4,7 +4,7 @@
 # Copyright (C) 2005 Florian Ragwitz <rafl@debian.org>, All Rights Reserved.
 # Copyright (C) 2005 Mike McCauley <mikem@open.com.au>, All Rights Reserved.
 #
-# $Id: SSLeay.pm 185 2007-07-03 14:06:29Z florian-guest $
+# $Id$
 #
 # Version 1.04, 31.3.1999
 # 30.7.1999, Tracking OpenSSL-0.9.3a changes, --Sampo
@@ -106,7 +106,7 @@ $Net::SSLeay::slowly = 0;
 $Net::SSLeay::random_device = '/dev/urandom';
 $Net::SSLeay::how_random = 512;
 
-$VERSION = '1.31_02';
+$VERSION = '1.33_01';
 @ISA = qw(Exporter);
 @EXPORT_OK = qw(
     AT_MD5_WITH_RSA_ENCRYPTION
@@ -185,6 +185,15 @@ $VERSION = '1.31_02';
     F_SSL_USE_RSAPRIVATEKEY_ASN1
     F_SSL_USE_RSAPRIVATEKEY_FILE
     F_WRITE_PENDING
+    GEN_OTHERNAME
+    GEN_EMAIL
+    GEN_DNS
+    GEN_X400
+    GEN_DIRNAME
+    GEN_EDIPARTY
+    GEN_URI
+    GEN_IPADD
+    GEN_RID
     MAX_MASTER_KEY_LENGTH_IN_BITS
     MAX_RECORD_LENGTH_2_BYTE_HEADER
     MAX_RECORD_LENGTH_3_BYTE_HEADER
@@ -200,6 +209,187 @@ $VERSION = '1.31_02';
     MT_SERVER_HELLO
     MT_SERVER_VERIFY
     NOTHING
+    NID_undef
+    NID_algorithm
+    NID_rsadsi
+    NID_pkcs
+    NID_md2
+    NID_md5
+    NID_rc4
+    NID_rsaEncryption
+    NID_md2WithRSAEncryption
+    NID_md5WithRSAEncryption
+    NID_pbeWithMD2AndDES_CBC
+    NID_pbeWithMD5AndDES_CBC
+    NID_X500
+    NID_X509
+    NID_commonName
+    NID_countryName
+    NID_localityName
+    NID_stateOrProvinceName
+    NID_organizationName
+    NID_organizationalUnitName
+    NID_rsa
+    NID_pkcs7
+    NID_pkcs7_data
+    NID_pkcs7_signed
+    NID_pkcs7_enveloped
+    NID_pkcs7_signedAndEnveloped
+    NID_pkcs7_digest
+    NID_pkcs7_encrypted
+    NID_pkcs3
+    NID_dhKeyAgreement
+    NID_des_ecb
+    NID_des_cfb64
+    NID_des_cbc
+    NID_des_ede
+    NID_des_ede3
+    NID_idea_cbc
+    NID_idea_cfb64
+    NID_idea_ecb
+    NID_rc2_cbc
+    NID_rc2_ecb
+    NID_rc2_cfb64
+    NID_rc2_ofb64
+    NID_sha
+    NID_shaWithRSAEncryption
+    NID_des_ede_cbc
+    NID_des_ede3_cbc
+    NID_des_ofb64
+    NID_idea_ofb64
+    NID_pkcs9
+    NID_pkcs9_emailAddress
+    NID_pkcs9_unstructuredName
+    NID_pkcs9_contentType
+    NID_pkcs9_messageDigest
+    NID_pkcs9_signingTime
+    NID_pkcs9_countersignature
+    NID_pkcs9_challengePassword
+    NID_pkcs9_unstructuredAddress
+    NID_pkcs9_extCertAttributes
+    NID_netscape
+    NID_netscape_cert_extension
+    NID_netscape_data_type
+    NID_des_ede_cfb64
+    NID_des_ede3_cfb64
+    NID_des_ede_ofb64
+    NID_des_ede3_ofb64
+    NID_sha1
+    NID_sha1WithRSAEncryption
+    NID_dsaWithSHA
+    NID_dsa_2
+    NID_pbeWithSHA1AndRC2_CBC
+    NID_id_pbkdf2
+    NID_dsaWithSHA1_2
+    NID_netscape_cert_type
+    NID_netscape_base_url
+    NID_netscape_revocation_url
+    NID_netscape_ca_revocation_url
+    NID_netscape_renewal_url
+    NID_netscape_ca_policy_url
+    NID_netscape_ssl_server_name
+    NID_netscape_comment
+    NID_netscape_cert_sequence
+    NID_desx_cbc
+    NID_id_ce
+    NID_subject_key_identifier
+    NID_key_usage
+    NID_private_key_usage_period
+    NID_subject_alt_name
+    NID_issuer_alt_name
+    NID_basic_constraints
+    NID_crl_number
+    NID_certificate_policies
+    NID_authority_key_identifier
+    NID_bf_cbc
+    NID_bf_ecb
+    NID_bf_cfb64
+    NID_bf_ofb64
+    NID_mdc2
+    NID_mdc2WithRSA
+    NID_rc4_40
+    NID_rc2_40_cbc
+    NID_givenName
+    NID_surname
+    NID_initials
+    NID_uniqueIdentifier
+    NID_crl_distribution_points
+    NID_md5WithRSA
+    NID_serialNumber
+    NID_title
+    NID_description
+    NID_cast5_cbc
+    NID_cast5_ecb
+    NID_cast5_cfb64
+    NID_cast5_ofb64
+    NID_pbeWithMD5AndCast5_CBC
+    NID_dsaWithSHA1
+    NID_md5_sha1
+    NID_sha1WithRSA
+    NID_dsa
+    NID_ripemd160
+    NID_ripemd160WithRSA
+    NID_rc5_cbc
+    NID_rc5_ecb
+    NID_rc5_cfb64
+    NID_rc5_ofb64
+    NID_rle_compression
+    NID_zlib_compression
+    NID_ext_key_usage
+    NID_id_pkix
+    NID_id_kp
+    NID_server_auth
+    NID_client_auth
+    NID_code_sign
+    NID_email_protect
+    NID_time_stamp
+    NID_ms_code_ind
+    NID_ms_code_com
+    NID_ms_ctl_sign
+    NID_ms_sgc
+    NID_ms_efs
+    NID_ns_sgc
+    NID_delta_crl
+    NID_crl_reason
+    NID_invalidity_date
+    NID_sxnet
+    NID_pbe_WithSHA1And128BitRC4
+    NID_pbe_WithSHA1And40BitRC4
+    NID_pbe_WithSHA1And3_Key_TripleDES_CBC
+    NID_pbe_WithSHA1And2_Key_TripleDES_CBC
+    NID_pbe_WithSHA1And128BitRC2_CBC
+    NID_pbe_WithSHA1And40BitRC2_CBC
+    NID_keyBag
+    NID_pkcs8ShroudedKeyBag
+    NID_certBag
+    NID_crlBag
+    NID_secretBag
+    NID_safeContentsBag
+    NID_friendlyName
+    NID_localKeyID
+    NID_x509Certificate
+    NID_sdsiCertificate
+    NID_x509Crl
+    NID_pbes2
+    NID_pbmac1
+    NID_hmacWithSHA1
+    NID_id_qt_cps
+    NID_id_qt_unotice
+    NID_rc2_64_cbc
+    NID_SMIMECapabilities
+    NID_pbeWithMD2AndRC2_CBC
+    NID_pbeWithMD5AndRC2_CBC
+    NID_pbeWithSHA1AndDES_CBC
+    NID_ms_ext_req
+    NID_ext_req
+    NID_name
+    NID_dnQualifier
+    NID_id_pe
+    NID_id_ad
+    NID_info_access
+    NID_ad_OCSP
+    NID_ad_ca_issuers
+    NID_OCSP_sign
     OPENSSL_VERSION_NUMBER
     PE_BAD_CERTIFICATE
     PE_NO_CERTIFICATE
@@ -1054,6 +1244,8 @@ Some very low level API functions are available:
     $server_random = Net::SSLeay::get_server_random($ssl);
     $session = Net::SSLeay::get_session($ssl);
     $master_key = Net::SSLeay::SESSION_get_master_key($session);
+    Net::SSLeay::SESSION_set_master_key($session, $master_secret);
+    $keyblocksize = Net::SSLeay::get_keyblock_size($session);
 
 =head2 HTTP (without S) API
 
@@ -1647,7 +1839,7 @@ sub open_proxy_tcp_connection {
     ($ret, $errs) =
 	tcp_write_all("CONNECT $dest_serv:$port HTTP/1.0$proxyauth$CRLF$CRLF");
     return wantarray ? (0,$errs) : 0 if $errs;
-    ($line, $errs) = tcp_read_until("\n", 1024);
+    ($line, $errs) = tcp_read_until($CRLF . $CRLF, 1024);
     warn "Proxy response: $line" if $trace>2;
     return wantarray ? (0,$errs) : 0 if $errs;
     return wantarray ? (1,'') : 1;  # Success
